import { Dag, IBlockService } from './dag/dag';
import CID from 'cids';
import { EcdsaKey } from '../crypto';
import { Transaction, TokenPayload } from 'tupelo-messages/transactions/transactions_pb';
import { Proof } from 'tupelo-messages/gossip/gossip_pb';
/**
 * The options to create a new ChainTree.
 * @public
 */
export interface IChainTreeInitializer {
    key?: EcdsaKey;
    tip: CID;
    store: IBlockService;
}
/**
 * ChainTree is the main class used for interacting with the data of Tupelo.
 * See {@link https://docs.quorumcontrol.com/docs/chaintree.html} for a detailed description
 * of what a ChainTree is.
 * @public
 */
export declare class ChainTree extends Dag {
    key?: EcdsaKey;
    store: IBlockService;
    /**
     * Creates a new empty chaintree using the specified key and blockservice.
     * @param store - The {@link IBlockService} to store the new blocks in (Community exports a block service)
     * @param key - The {@link EcdsaKey} to use to name the ChainTree (this is used to create the DID)
     * @public
     */
    static newEmptyTree: (store: IBlockService, key: EcdsaKey) => Promise<ChainTree>;
    /**
     * getLatest returns a ChainTree with the newest state already cached in the local repo
     * @param did - the did of the tree
     * @public
     */
    static getLatest: (did: string) => Promise<ChainTree>;
    /**
     * Creates a new ChainTree
     * @param opts - {@link IChainTreeInitializer}
     * @public
     */
    constructor(opts: IChainTreeInitializer);
    /**
     * resolveData is the mirror image of setData. It starts at the data section
     * of a ChainTree. This allows you to ignore the "tree/data" part of a path (as is done
     * in setData)
     * @param path - the path (starting after /tree/data) you want to resolve
     */
    resolveData(path: string): Promise<import("./dag/dag").IResolveResponse>;
    /**
     * Returns the DID of the ChainTree
     * @public
     */
    id(): Promise<string | null>;
}
/**
 * returns a setOwnershipTransaction
 * @param newOwnerKeys - An array of the addresses of the new owners
 * @public
 */
export declare const setOwnershipTransaction: (newOwnerKeys: string[]) => Transaction;
/**
 * Returns a setDataTransaction
 * @param path - The path of the Tree to set
 * @param value - An object to set at the path (this will be CBOR encoded for you).
 * @public
 */
export declare const setDataTransaction: (path: string, value: any) => Transaction;
/**
 * Returns a new establishTokenTransaction which is used to setup the monetary policy
 * of a new token on a ChainTree
 * @public
 */
export declare const establishTokenTransaction: (name: string, maximum: number) => Transaction;
/**
 * @public
 */
export declare const mintTokenTransaction: (name: string, amount: number) => Transaction;
/**
 * @public
 */
export declare const sendTokenTransaction: (sendId: string, name: string, amount: number, destinationChainId: string) => Transaction;
/**
 * @public
 */
export declare const receiveTokenTransaction: (sendId: string, tip: Uint8Array, proof: Proof, leaves: Uint8Array[]) => Transaction;
/**
 * This function is useful if you have the full payload from the send token sent to you
 * no need to deconstruct and the reconstruct the payload. Often wallets will send this payload as base64.
 *
 * @param payload - The receive token payload
 * @public
 */
export declare const receiveTokenTransactionFromPayload: (payload: TokenPayload) => Transaction;
export default ChainTree;
//# sourceMappingURL=chaintree.d.ts.map